Package 'mdrb'

Title: Metabodecon Rust Backend
Description: Provides a high-performance Rust backend for the 'metabodecon' package (<https://github.com/spang-lab/metabodecon>), enabling efficient deconvolution, alignment, and post-processing of 1-dimensional (1D) nuclear magnetic resonance (NMR) spectra. The package wraps optimized Rust functions to improve performance and scalability for large datasets. The recommended way to use *mdrb* is by installing *metabodecon* and setting the backend argument to "rust" when calling its functions. The Rust part of the package is based on the 'metabodecon-rust' crate (<https://github.com/SombkeMaximilian/metabodecon-rust>).
Authors: Tobias Schmidt [aut, cre, cph], Maximilian Sombke [aut, cph], Wolfram Gronwald [aut, cph]
Maintainer: Tobias Schmidt <[email protected]>
License: GPL (>= 3)
Version: 0.0.5
Built: 2026-05-31 02:52:50 UTC
Source: https://github.com/spang-lab/mdrb

Help Index


Deconvoluter Class

Description

Environment containing methods for the Deconvoluter class.

Usage

Deconvoluter

Format

An object of class environment of length 19.

Methods

x <- Deconvoluter$new()  
x$add_ignore_region(start, end)  
x$clear_ignore_regions()  
x$clear_threads()  
x$deconvolute_spectra(spectra)  
x$deconvolute_spectrum(spectrum)  
x$fitting_settings()  
x$ignore_regions()  
x$optimize_settings(reference)  
x$par_deconvolute_spectra(spectra)  
x$par_deconvolute_spectrum(spectrum)  
x$selection_settings()  
x$set_analytical_fitter(iterations)  
x$set_detector_only()  
x$set_identity_smoother()  
x$set_moving_average_smoother(iterations, window_size)  
x$set_noise_score_selector(threshold)  
x$set_threads(threads)  
x$smoothing_settings()  

For more information on the methods, see the Rust documentation at https://github.com/SombkeMaximilian/metabodecon-rust.


Deconvolution Class

Description

Environment containing methods for the Deconvolution class.

Usage

Deconvolution

Format

An object of class environment of length 9.

Methods

# Assuming x is an object of class Deconvolution
x$lorentzians()  
x$mse()  
x$par_superposition_vec(chemical_shifts)  
x$read_bin(path)  
x$read_json(path)  
x$superposition(chemical_shift)  
x$superposition_vec(chemical_shifts)  
x$write_bin(path)  
x$write_json(path)  

For more information on the methods, see the Rust documentation at https://github.com/SombkeMaximilian/metabodecon-rust.


Lorentzian Class

Description

Environment containing methods for the Lorentzian class.

Usage

Lorentzian

Format

An object of class environment of length 12.

Methods

x <- Lorentzian$new(sf, hw, maxp)  
x$evaluate(x)  
x$evaluate_vec(x)  
x$hw()  
x$maxp()  
x$par_superposition_vec(x, sf, hw, maxp)  
x$set_hw(hw)  
x$set_maxp(maxp)  
x$set_sf(sf)  
x$sf()  
x$superposition(x, sf, hw, maxp)  
x$superposition_vec(x, sf, hw, maxp)  

For more information on the methods, see the Rust documentation at https://github.com/SombkeMaximilian/metabodecon-rust.


Spectrum Class

Description

Environment containing methods for the Spectrum class.

Usage

Spectrum

Format

An object of class environment of length 18.

Methods

x <- Spectrum$new(chemical_shifts, intensities, signal_boundaries)  
x$chemical_shifts()  
x$frequency()  
x$intensities()  
x$nucleus()  
x$read_bin(path)  
x$read_bruker(path, experiment, processing, signal_boundaries)  
x$read_bruker_set(path, experiment, processing, signal_boundaries)  
x$read_jcampdx(path, signal_boundaries)  
x$read_json(path)  
x$reference_compound()  
x$set_frequency(frequency)  
x$set_nucleus(nucleus)  
x$set_reference_compound(reference)  
x$set_signal_boundaries(signal_boundaries)  
x$signal_boundaries()  
x$write_bin(path)  
x$write_json(path)  

For more information on the methods, see the Rust documentation at https://github.com/SombkeMaximilian/metabodecon-rust.